/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef IN16BSAMPLESEQUENCER_H_
#define IN16BSAMPLESEQUENCER_H_


#include "InstrumentAbstraction/Lss/SampleSequencer.h"
#include "controllers/spectrometer/QE65000Controller.h"

using namespace spectrometer;
//using namespace d22;

namespace d22special {

class D22SampleSequencer : public ::SampleSequencer {

public:

	static const std::string TYPE;

	D22SampleSequencer(const std::string & name);

	virtual ~D22SampleSequencer();

	DynamicProperty<int32> useSpectro;
	Property<int32> integrationTime;
	Property<int32> scansToAverage;

	ControllerPtr<QE65000Controller> spectroController;

	virtual void postConfiguration();

	virtual void execute(const string& command, bool blocking, bool logging = false);

	virtual void updateProperty(ChangeAspect* aChangeAspect);

	virtual void refreshSetValue(string propertyName, const boost::any aValue) throw (CannotSetValue);


	//new things here!

//	virtual void start();
//	virtual void stop();

//	virtual void updateActualSlot();
//	virtual void updateStatusMessage();
//	virtual void updateNumor();
//	virtual void updateIntegrationTime();
//	virtual void updateScansToAverage();

private:

	void getSpectro();
	void doLastMeasure();

	int32 actualSlotNumber;
	int32 lastNumor;

	bool m_started;
};

}

#endif
