/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef DUALSWITCHSPECTROCONTROLLER_H_
#define DUALSWITCHSPECTROCONTROLLER_H_

#include "controllers/spectrometer/QE65000Controller.h"
#include "controllers/common/state/stateio/ShutterController.h"

using namespace spectrometer;

namespace d22special {

class DualSwitchSpectroController : public ExperimentController, public controller::Stoppable {

public:
	static const std::string TYPE;

	Property<int32> integrationTime;
	Property<int32> numberOfCycles;
	Property<std::string> executionStatus;

	ArrayProperty<float64> xData;
	ArrayProperty<float64> xLeftData;
	ArrayProperty<float64> yLeftData;
	ArrayProperty<float64> yRightData;

	bool m_StopActivated;

	DualSwitchSpectroController(const std::string& name);
	virtual ~DualSwitchSpectroController();

	ControllerPtr<spectrometer::QE65000Controller> spectroController;
	ControllerPtr<stateio::ShutterController> switcherController;

	virtual void start();
	virtual void stop();

	void postConfiguration();
	void updateProgression();
	void updateData();

};

}

#endif
