/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef NPP_REMOTEDPPHISTOGRAM_H
#define NPP_REMOTEDPPHISTOGRAM_H

#include "../npp/DPPLiveProcess.h"
#include "DPPReader.h"
#include <nappli/nappli.h>
#include <boost/thread.hpp>
#include <stdint.h>
#include <memory>

namespace npp {

class RemoteDPPHistogram : public DPPLiveProcess {

public:
	//! Type of controller
	static const std::string TYPE;

	RemoteDPPHistogram(const std::string& name);
	RemoteDPPHistogram(const RemoteDPPHistogram& controller);
	virtual ~RemoteDPPHistogram();

	virtual void postConfiguration();
	virtual void setDetectorControllers(const std::vector<ControllerPtr<acquisition::DetectorController> > & detectorControllers);

	virtual void start();
	virtual void stop();
	virtual void raz();

	void updateListModeData(int index);

private:
	void resetData();
	std::auto_ptr<DPPReader> initTest();
	void testLoop(DPPReader * reader);
	std::auto_ptr<boost::thread> startTest(DPPReader * reader);
	void finishTest(std::auto_ptr<boost::thread> thread);

	Property<std::string> serverEndpoint;
	Property<int32> triggerChannel;
	Property<int32> delay;
	Property<int32> dT;
	Property<int32> maxBlock;
	Property<int32> blockSize;
	Property<bool> test;
	Property<std::string> testFileName;
	ArrayProperty<int32> xData;
	Property<int32> one;
	Property<int32> refreshTimeS;
	DynamicArrayProperty<int32> histogram;
	DynamicProperty<int32> ADCId;
	DynamicProperty<float64> ADCRate;

	std::auto_ptr<nappli::Server> m_server;
	std::auto_ptr<nappli::Application::Future> m_histoApplication;
	auto_ptr<nappli::Application::Publisher> m_publisher;

	static const int32 MAX_ADC = 128;
};

}

#endif
