/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "SimulatedQE65000Driver.h"

namespace oceanoptics {

SimulatedQE65000Driver::SimulatedQE65000Driver(QE65000Driver* owner) : QE65000State(owner) {

}

SimulatedQE65000Driver::~SimulatedQE65000Driver() {

}

void SimulatedQE65000Driver::init() {

}

void SimulatedQE65000Driver::measure() {
	//Simulate integrationTime taken into account
	usleep(owner()->integrationTime());

	//Assume spectrum length is always the same (1044)
	int32 length = 1044;
	float64* tempXData = new float64[length];
	float64* tempYData = new float64[length];

	for (int32 j = 0; j < length; j++) {
		tempXData[j] = j;
		tempYData[j] = j + 100;
	}

	owner()->xData.set(tempXData);
	owner()->xData.setSize(length);

	owner()->yData.set(tempYData);
	owner()->yData.setSize(length);
}

void SimulatedQE65000Driver::stop() {
	m_owner->sendProgressEvent(PROGRESSION_END_DEVICE_CONTAINER);
}

void SimulatedQE65000Driver::readStatus() {
//	cout << "reading status in perfect mode" << endl;
}

}


