/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef STEREOELECSTATE_H
#define STEREOELECSTATE_H

#include <Driver.h>
#include "StereoElecDriver.h"

namespace stereo_elec {

/*!
 * \class StereoElecState
 * \brief Implements State pattern
 */
class StereoElecState: public DriverState<StereoElecDriver> {

public:

	/*!
	 * \brief Constructor.
	 */
	StereoElecState(StereoElecDriver* owner) :
			DriverState<StereoElecDriver>(owner) {
	}

	/*!
	 * \brief Destructor.
	 */
	virtual ~StereoElecState() {
	}

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus() = 0;

	/*!
	 * \brief Start command implementation
	 */
	virtual void start() = 0;

	/*!
	 * \brief Read command implementation
	 */
	virtual void read() = 0;

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead() = 0;

	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop() = 0;

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos() = 0;

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam() = 0;

	/*!
	 * \brief Clear command implementation
	 */
	//virtual void clear() = 0;

	virtual void config() = 0;


};

}

#endif //STEREOELECSTATE_H
